"""Full documentation is at https://photini.readthedocs.io/"""

__version__ = '2022.10.0.2'
build = '2278 (08b9228)'
